cin=scanf=i=input
documentwrite=ip=cout=printf=P=p=ଦେଖ=see=देखना=आउटपुट_देखना=ي=изглед=视图=視圖=pogled=Pohled=udsigt=visie=vidon=vaade=näkymä=vue=Aussicht=θέα=נוף=melihat=Visualizza=見る=전망=skats=vaizdas=utsikt=widok=Visão=vedere=Посмотреть=поглед=vyhliadka=pogled=ver=se=намоиш=ดู=görünüm=вид=lượtxem=دیکھیں=వీక్షణ=பார்வை=पहा=കാണുക=pandangan=tingnan=vista=দৃশ্য=print




import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="PRINTSHORTCUT", # Replace with your own username
    version='0.0.1',
    author="KESHARI NANDANA PRATAP",
    author_email='kesharipratap52@gmail.com',
    description="Print and input shortcut",
    long_description=open('README.MD').read() + '\n\n' + open('CHANGELOG.txt').read(),
    long_description_content_type="text/markdown",
    url="https://knpjg.blogspot.com/2020/07/my-own-python-shortcutio-libiary.html",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0',
)